@@ -235,7 +235,7 @@ func EncodeTransaction(params *C.char, signs *C.char) *C.char {
 		return renderError(err)
 	}
 
-	signed := trx.AsLatestVersion()
+	signed := trx.AsVersioned()
 	return renderData(hex.EncodeToString(signed.Marshal()))
 }
 
@@ -269,7 +269,7 @@ func SignTransaction(_params *C.char) *C.char {
 		}
 	}
 
-	tx := common.NewTransaction(params.Raw.Asset)
+	tx := common.NewTransactionV3(params.Raw.Asset)
 	for _, in := range params.Raw.Inputs {
 		if d := in.Deposit; d != nil {
 			tx.AddDepositInput(&common.DepositData{
@@ -327,7 +327,7 @@ func SignTransaction(_params *C.char) *C.char {
 		accounts = append(accounts, &account)
 	}
 
-	signed := tx.AsLatestVersion()
+	signed := tx.AsVersioned()
 	for _, inputIndex := range params.InputIndexes {
 		err = signed.SignInput(params.Raw, int(inputIndex), accounts)
 		if err != nil {
@@ -517,7 +517,7 @@ func BuildRawTransaction(_params *C.char) *C.char {
 		return renderError(err)
 	}
 
-	tx := common.NewTransaction(asset)
+	tx := common.NewTransactionV3(asset)
 	for _, in := range inputs {
 		tx.AddInput(in["hash"].(crypto.Hash), in["index"].(int))
 	}
@@ -526,7 +526,7 @@ func BuildRawTransaction(_params *C.char) *C.char {
 	}
 	tx.Extra = extra
 
-	signed := tx.AsLatestVersion()
+	signed := tx.AsVersioned()
 	for i := range tx.Inputs {
 		err = signed.SignInput(raw, i, []*common.Address{&account})
 		if err != nil {
@@ -585,12 +585,12 @@ func PledgeNode(_params *C.char) *C.char {
 
 	amount := common.NewIntegerFromString(params["amount"])
 
-	tx := common.NewTransaction(common.XINAssetId)
+	tx := common.NewTransactionV3(common.XINAssetId)
 	tx.AddInput(input, 0)
 	tx.AddOutputWithType(common.OutputTypeNodePledge, nil, common.Script{}, amount, seed)
 	tx.Extra = append(signer.PublicSpendKey[:], payee.PublicSpendKey[:]...)
 
-	signed := tx.AsLatestVersion()
+	signed := tx.AsVersioned()
 	err = signed.SignInput(raw, 0, []*common.Address{&account})
 	if err != nil {
 		return renderError(err)
@@ -671,7 +671,7 @@ func CancelNode(_params *C.char) *C.char {
 		return renderError(err)
 	}
 
-	tx := common.NewTransaction(common.XINAssetId)
+	tx := common.NewTransactionV3(common.XINAssetId)
 	tx.AddInput(pledge.PayloadHash(), 0)
 	tx.AddOutputWithType(common.OutputTypeNodeCancel, nil, common.Script{}, pledge.Outputs[0].Amount.Div(100), seed)
 	tx.AddScriptOutput([]*common.Address{&receiver}, common.NewThresholdScript(1), pledge.Outputs[0].Amount.Sub(tx.Outputs[0].Amount), seed)
@@ -687,7 +687,7 @@ func CancelNode(_params *C.char) *C.char {
 			Mask: source.Outputs[0].Mask,
 		},
 	}
-	signed := tx.AsLatestVersion()
+	signed := tx.AsVersioned()
 	err = signed.SignUTXO(utxo, []*common.Address{&account})
 	if err != nil {
 		return renderError(err)
@@ -789,14 +789,14 @@ func BuildTransactionWithGhostKeys(assetId_ *C.char, ghostKeys_ *C.char, trxHash
 	}
 
 	tx := &common.Transaction{
-		Version: common.TxVersion,
+		Version: common.TxVersionBlake3Hash,
 		Inputs:  []*common.Input{&common.Input{Hash: _trxHash, Index: outputIndex_}},
 		//		Outputs: []*Output{&Output{Mask: keys.Mask, Keys: keys.Keys, Amount: outputAmount, Script: "fffe01"}},
 		Outputs: outputs,
 		Asset:   _assetId,
 		Extra:   _memo,
 	}
-	signed := tx.AsLatestVersion()
+	signed := tx.AsVersioned()
 	return renderData(hex.EncodeToString(signed.Marshal()))
 }
 
